@@ -23,12 +23,15 @@ import cl_overriding
 from cl_vars_share import varsShare, clLocale
 from os.path import exists as pathexists
 from os import path
-from cl_utils import isMount
+from cl_utils import isMount, genpassword
+from encrypt import getHash
 
 class fillVars(varsShare):
     """Auxilary object for creating variables
     
     Contains filling methods"""
+    addDn = lambda x,*y: ",".join(y)
+    genDn = lambda x,*y: "=".join(y)
 
     def get_cl_env_path(self):
         """Path to env files"""
@@ -50,6 +53,16 @@ class fillVars(varsShare):
                 _("Template variable cl_env_data is empty"))
             cl_overriding.exit(1)
 
+    def get_cl_env_server_path(self):
+        """Paths to clt-template files"""
+        return '/var/calculate/remote/server.env'
+
+    def get_cl_template_path(self):
+        """Paths to template files"""
+        return ["/usr/share/calculate/templates",
+                "/var/calculate/templates",
+                "/var/calculate/remote/templates"]
+
     def get_cl_template_clt_path(self):
         """Path to 'clt' files"""
         if "CONFIG_PROTECT" in os.environ:
@@ -313,12 +326,12 @@ class fillVars(varsShare):
         localeVal = self.getValueFromCmdLine("calculate",0)
         if locale.isLangExists(localeVal):
             return locale.getFieldByLang('locale',localeVal)
-        elif os.environ.has_key("LANG"):
-            return os.environ["LANG"]
         else:
             localeVal = self.getValueFromConfig('/etc/env.d/02locale','LANG')
             if locale.isValueInFieldExists('locale',localeVal):
                 return localeVal
+        if os.environ.has_key("LANG"):
+            return os.environ["LANG"]
         return locale.getFieldByLang("locale","default")
 
     def get_os_locale_lang(self):
@@ -552,6 +565,14 @@ class fillVars(varsShare):
                         "unknown"
         return ""
 
+    def get_hr_laptop_model(self):
+        """Laptop name"""
+        boardName = '/sys/class/dmi/id/board_name'
+        if self.Get('hr_laptop') and os.access(boardName,os.R_OK):
+            valBoardName = open(boardName,'r').read().strip()
+            return valBoardName or "unknown"
+        return ""
+
     def get_hr_video(self):
         """Videocard vendor"""
         lines=self._runos("lspci")
@@ -594,9 +615,103 @@ class fillVars(varsShare):
         else:
             return ""
 
+    def get_cl_chroot_status(self):
+        """Detect chroot mode by mtab content"""
+        try:
+            return "on" if self.isChroot(os.getpid()) else "off"
+        except:
+            return "off"
+
     def get_os_scratch(self):
         """Current system is scratch"""
         if self.Get('os_root_type') == 'livecd':
             return "on" if isMount('/mnt/scratch/workspace') else "off"
         else:
             return "on" if isMount('/mnt/scratch') else "off"
+
+    def get_cl_root_path(self):
+        """Path to directory relative which perform joining templates to 
+
+        system files (sandbox)"""
+        return '/'
+
+    def get_cl_chroot_path(self):
+        """Path to directory which contain other system"""
+        return '/'
+
+    def get_cl_autoupdate_set(self):
+        """(on or off) autoupdate config from install program"""
+        return 'off'
+
+    def get_cl_api(self):
+        """The path to the module api,
+
+        and additional parameters caluclate packages"""
+        return {}
+
+    def get_ld_encrypt(self):
+        """hash crypto algoritm"""
+        return 'ssha'
+
+    def get_ld_bind_login(self):
+        """bind login"""
+        return 'proxyuser'
+
+    def get_ld_base_root(self):
+        """base name LDAP"""
+        return 'calculate'
+
+    def get_ld_base_dn(self):
+        """base DN LDAP"""
+        return self.genDn("dc", self.Get('ld_base_root'))
+
+    def get_ld_bind_dn(self):
+        """bind DN LDAP"""
+        return self.addDn(self.genDn("cn", self.Get('ld_bind_login')),
+                          self.Get('ld_base_dn'))
+
+    def get_ld_bind_pw(self):
+        """bind password"""
+        return 'calculate'
+
+    def get_ld_bind_hash(self):
+        """hash bind"""
+        return getHash(self.Get('ld_bind_pw'), self.Get('ld_encrypt'))
+
+    def get_ld_admin_login(self):
+        """administrator name"""
+        return 'ldapadmin'
+
+    def get_ld_admin_dn(self):
+        """root DN"""
+        return self.addDn(self.genDn("cn", self.Get('ld_admin_login')), 
+                          self.Get('ld_base_dn'))
+
+    def get_ld_admin_hash(self):
+        """root hash"""
+        return getHash(self.Get('ld_admin_pw'), self.Get('ld_encrypt'))
+
+    def get_ld_admin_pw(self):
+        """password root"""
+        return genpassword()
+
+    def get_ld_services(self):
+        """Name from all services"""
+        return 'Services'
+
+    def get_ld_services_dn(self):
+        """DN from all services"""
+        return self.addDn(self.genDn("ou", self.Get('ld_services')), 
+                          self.Get('ld_base_dn'))
+
+    def get_cl_ca_cert(self):
+        """CA certificate"""
+        return 'CA.crt'
+
+    def get_cl_ca_key(self):
+        """CA key"""
+        return 'CA.key'
+
+    def get_cl_ca_path(self):
+        """CA path"""
+        return '/var/calculate/ssl/main'
