@@ -232,10 +232,14 @@ class process:
 
     def read(self):
         """Read all data"""
-        self._open()
-        if self.cacheresult is None:
-            self.cacheresult = self.pipe.communicate()[0]
-        return self.cacheresult
+        try:
+            self._open()
+            if self.cacheresult is None:
+                self.cacheresult = self.pipe.communicate()[0]
+            return self.cacheresult
+        except KeyboardInterrupt:
+            self.kill()
+            raise KeyboardInterrupt
 
     def readlines(self):
         """Read lines"""
@@ -247,15 +251,18 @@ class process:
             self.iter = iter(self.readlines())
         return self.iter
 
+    def kill(self):
+        """Kill this process"""
+        if self.pipe:
+            self.pipe.kill()
+
     def next(self):
         """Next string from stdout"""
         return self.__iter__().next()
 
     def returncode(self):
         """Get return code"""
-        self._open()
-        if self.pipe.returncode is None:
-            self.cacheresult = self.pipe.communicate()[0]
+        self.read()
         return self.pipe.returncode
 
     def success(self):
@@ -266,6 +273,61 @@ class process:
         """Failed or not"""
         return self.returncode() != 0
 
+class processProgress(process):
+    """Execute system command by Popen for parse stdout."""
+    
+    def __init__(self,command,*params,**kwarg):
+        process.__init__(self,command,*params,**kwarg)
+        self.readsize = kwarg.get("readsize",10)
+        self.init(**kwarg)
+
+    def init(self,**kwarg):
+        pass
+
+    def read(self):
+        """Read data with parsing ability"""
+        try:
+            self.processInit()
+            self._open()
+            if self.cacheresult is None:
+                self.cacheresult = []
+                self.buf = ""
+                part = self.pipe.stdout.read(1)
+                while part:
+                    if self.buf:
+                        self.buf += part
+                    else:
+                        self.buf = part
+                    if self.processStdout():
+                        self.processDraw()
+                    self.cacheresult.append(part)
+                    part = self.pipe.stdout.read(self.readsize)
+                self.pipe.poll()
+                self.processEnd(self.success())
+        except KeyboardInterrupt:
+            self.cacheresult = "".join(self.cacheresult)
+            self.pipe.kill()
+            self.processEnd(False)
+            raise KeyboardInterrupt()
+        self.cacheresult = "".join(self.cacheresult)
+        return self.cacheresult
+
+    def processInit(self):
+        """Called when read first byte"""
+        pass
+
+    def processDraw(self):
+        """Called when processStdout return True"""
+        pass
+
+    def processStdout(self):
+        """Called when read readsize byte from stdout"""
+        return True
+
+    def processEnd(self,res=True):
+        """Called when process end"""
+        pass
+
 def runOsCommand(cmd,in_str=None, env_dict=None):
     """Выполняет внешнюю программу
 
@@ -438,7 +500,7 @@ def convertStrListDict(val):
         if re.match("^{.*}$",val):
             return str2dict(val)
         # detect list
-        elif re.match("^[.*]$",val):
+        elif re.match("^\[.*\]$",val):
             return str2list(val)
         # else is simple string
         else:
@@ -516,11 +578,40 @@ def removeDir(rmDir):
 
 def getRunCommands():
     """List run program"""
+    def getCmd(procNum):
+        cmdLineFile = '/proc/%s/cmdline'%procNum
+        try:
+            if os.path.exists(cmdLineFile):
+                return open(cmdLineFile,'r').read().strip()
+        except:
+            pass
+        return ""
     if not os.access('/proc',os.R_OK):
         return []
-    return map(lambda x:open('/proc/%s/cmdline'%x).read().strip(),
-               filter(lambda x:x.isdigit(),
-                      os.listdir('/proc')))
+    return map(getCmd,filter(lambda x:x.isdigit(),
+                              os.listdir('/proc')))
+
+def isFstabMount(pathname):
+    """Get mount point or device from fstab"""
+    if pathname == "swap":
+        absPath = "swap"
+    else:
+        absPath = os.path.abspath(pathname)
+    # convert fstab to
+    # [['/dev/sda3', '/', '', 'reiserfs', 'noatime', '', '', '0', '2\n'],
+    # ['/dev/sda5', '/var/calculate', 'reiserfs', 'noatime', '0', '0\n']]
+    listFstab = filter(lambda x: len(x) >= 4,
+                map(lambda x: filter(lambda x: x,
+                                     x.replace('\t',' ').split(' ')),
+                    filter(lambda x: not x.startswith('#') and x.strip(),
+                           open("/etc/fstab"))))
+    # get mount point or device or dir
+    return filter(lambda x: x!=absPath,
+                  reduce(lambda x,y: y,
+                         filter(lambda x: absPath in x and x[1] != "none",
+                                map(lambda x: [x[0],
+                                    x[1] if x[2] != "swap" else "swap"],
+                                    listFstab)),[""]))[0]
 
 def isMount(path):
     """В случае монтирования директории выдает другой примонтированный путь"""
@@ -533,6 +624,30 @@ def isMount(path):
                          map(lambda x: [x[0], x[1]], map(lambda x: x.split(" "),
                              open(mtabFile)))),[""]))[0]
 
+def commonPath(*paths):
+    """Return common path from list of paths"""
+    paths = map(lambda x:os.path.normpath(x).split('/'),paths)
+    res = map(lambda x:x[0],
+        filter(lambda x:filter(lambda y:x[0]==y,x[1:]),zip(*paths)))
+    return "/".join(res)
+
+def childMounts(path):
+    """Get all mount points which contain path"""
+    if path != "none":
+        absPath = os.path.abspath(path)
+    else:
+        absPath = path
+    mtabFile = '/etc/mtab'
+    if not os.access(mtabFile,os.R_OK):
+        return ""
+    return reduce(lambda x,y: x + [y],
+                  filter(lambda x: commonPath(absPath,x[0])==absPath or \
+                                   commonPath(absPath,x[1])==absPath,
+                         map(lambda x: [x[0], x[1]],
+                             map(lambda x: x.split(" "),
+                                 open(mtabFile)))),
+                  [])
+
 def pathJoin(*paths):
     """Складывает пути, в отличии от os.path.join, складывает абсолютные пути"""
     if len(paths)==1:
@@ -615,3 +730,25 @@ def removeProgramToEnvFile(nameProg, objVar):
     if not objVar.WriteList("cl_merges", force=True):
         return False
     return True
+
+def checkDigestFile(digestfile):
+    """Check digest by digestfile"""
+    reEntry = re.compile(r"# (\S+) HASH\n(\S+)  (\S+)",re.S)
+    result = []
+    for alg,hashdata,filename in \
+        reEntry.findall(open(digestfile,'r').read()):
+        if hasattr(hashlib,alg.lower()):
+            hashobj = getattr(hashlib,alg.lower())
+            filename = os.path.join(os.path.dirname(digestfile),filename)
+            if os.path.exists(filename):
+                digest = hashobj(open(filename,'r').read())
+                result.append((alg,
+                    digest.hexdigest().upper() == hashdata.upper()))
+    return result
+
+def getFilesCount(directory):
+    """Get files count from directory"""
+    if os.path.exists(directory):
+        return len(reduce(lambda x,y:x+y,map(lambda x:x[1]+x[2],
+                          os.walk(directory)),[]))
+    return 0
