@@ -19,176 +19,228 @@
 #              'r' you cann't change value from command line
 #   type     - depricated
 #   value    - value 
-#   official - show or not variable for display values
+#   hide - show or not variable for display values
 
 class Data:
     # computer hostname
-    os_net_hostname = {'mode':"w"}
+    os_net_hostname = {'hide':True, 'mode':"w"}
 
     # allowed networks
-    os_net_allow ={}
+    os_net_allow ={'hide':True}
 
     # ip for all network interfaces (comma delimeter)
-    os_net_ip ={}
+    os_net_ip ={'hide':True}
 
     # network interfaces
-    os_net_interfaces={'official':True}
+    os_net_interfaces={'hide':True}
 
     # computer domain
-    os_net_domain = {'mode':"w"}
+    os_net_domain = {'hide':True, 'mode':"w"}
 
     # short system name (CLD)
-    os_linux_shortname={}
+    os_linux_shortname={'hide':True}
 
     # aliases and path to ini files
-    cl_env_data = {'official':True,
+    cl_env_data = {'hide':True,
                    'value':[('default', '/etc/calculate/calculate2.env'),
                             ('local', '/var/calculate/calculate2.env'),
                             ('remote', '/var/calculate/remote/calculate2.env')]}
 
     # path aliases to ini files (from cl_env_data)
-    cl_env_location = {'official':True}
+    cl_env_location = {'hide':True}
 
     # path to ini files (from cl_env_data)
-    cl_env_path = {}
+    cl_env_path = {'hide':True}
 
     # path to information file on server
-    cl_env_server_path = {'official':True,
-                          'value':'/var/calculate/remote/server.env'}
+    cl_env_server_path = {'hide':True}
 
     # paths to template files
-    cl_template_path = {'value':["/usr/share/calculate/templates",
-                                 "/var/calculate/templates",
-                                 "/var/calculate/remote/templates"]}
-     # paths to clt-template files
-    cl_template_clt_path = {}
+    cl_template_path = {'hide':True}
+
+    # paths to clt-template files
+    cl_template_clt_path = {'hide':True}
+
+    # is shell in chroot
+    cl_chroot_status = {'hide':True}
+
     # locale (at example: ru_RU.UTF-8)
-    os_locale_locale = {}
+    os_locale_locale = {'hide':True}
+
     # full language (at example: ru_RU)
-    os_locale_lang = {}
+    os_locale_lang = {'hide':True}
+
     # short language (at example ru)
-    os_locale_language = {}
+    os_locale_language = {'hide':True}
 
     # keyboard layout for X server
-    os_locale_xkb = {}
+    os_locale_xkb = {'hide':True}
 
     # keyboard layout name for X server
-    os_locale_xkbname = {}
+    os_locale_xkbname = {'hide':True}
 
     # computer architecture (i686,x86_64)
-    os_arch_machine = {}
+    os_arch_machine = {'hide':True}
 
     # pass for templates join 1,2,3,4,5 and etc
-    cl_pass_step = {}
+    cl_pass_step = {'hide':True}
 
     # template file performed at now
-    cl_pass_file = {'mode':"w"}
+    cl_pass_file = {'hide':True, 'mode':"w"}
 
     # root partition of filesystem
-    os_root_dev = {}
+    os_root_dev = {'hide':True}
 
     # root type (ram, hdd, usb-hdd, livecd)
-    os_root_type = {}
+    os_root_type = {'hide':True}
 
     # full system name
-    os_linux_name = {}
+    os_linux_name = {'hide':True}
 
     # postfix to system name (KDE GNOME and etc)
-    os_linux_subname = {}
+    os_linux_subname = {'hide':True}
 
     # system (desktop or server)
-    os_linux_system = {}
+    os_linux_system = {'hide':True}
 
     # motherboard model
-    hr_board_model = {}
+    hr_board_model = {'hide':True}
 
     # motherboard vendor
-    hr_board_vendor = {}
+    hr_board_vendor = {'hide':True}
 
     # processors count
-    hr_cpu_num = {}
+    hr_cpu_num = {'hide':True}
 
     # virtual machine name (virtualbox, vmware, qemu)
-    hr_virtual = {}
+    hr_virtual = {'hide':True}
 
     # system version
-    os_linux_ver = {}
+    os_linux_ver = {'hide':True}
  
     # user login
-    ur_login = {}
+    ur_login = {'hide':True}
 
     # user group name
-    ur_group = {'official':True}
+    ur_group = {'hide':True}
 
     # user fullname
-    ur_fullname = {'official':True}
+    ur_fullname = {'hide':True}
 
     # user home directory
-    ur_home_path = {'official':True}
+    ur_home_path = {'hide':True}
 
     # path to directory relative which perform joining templates to system files
     # (sandbox)
-    cl_root_path = {'mode':"w", 'value':"/"}
+    cl_root_path = {'hide':True, 'mode':"w"}
 
     # path to directory which contain other system
-    cl_chroot_path = {'mode':"r", 'value':"/"}
+    cl_chroot_path = {'hide':True}
 
     # program action
     # install, uninstall, merge, domain, undomain, system, desktop
-    cl_action = {}
+    cl_action = {'hide':True}
 
     # program state
     # specifies addition to cl_pass_action for needing
-    cl_pass_state = {}
+    cl_pass_state = {'hide':True}
 
     # User Jabber ID
-    ur_jid = {'official':True}
+    ur_jid = {'hide':True}
 
     # user email
-    ur_mail = {'official':True}
+    ur_mail = {'hide':True}
 
     # kernel uid get by uuid root device
-    cl_kernel_uid = {}
-    # variable for calculate-client and calculate-desktop packages
-    # ip or domain name of CDS
-    cl_remote_host = {'mode':'r', 'official':True}
+    cl_kernel_uid = {'hide':True}
 
     # this variable work with template function belong(package_name)
     # if the variable is defined then will use only template, which 
     # has package_name in belong equal value of this variable or
     # hasn't belong function
     # (package_name == value of cl_belong_pkg)
-    cl_belong_pkg = {'mode':'r', 'official':True}
+    cl_belong_pkg = {'mode':'r', 'hide':True}
 
     # vertical resolution for X server
-    os_x11_height = {'mode':"w"}
+    os_x11_height = {'mode':"w", 'hide':True}
 
     # horizontal resolution for X server
-    os_x11_width = {'mode':"w"}
+    os_x11_width = {'mode':"w", 'hide':True}
 
     # the nearest standard size of image to current screen resolution
-    os_x11_standart = {}
+    os_x11_standart = {'hide':True}
 
-    # if computer is noteboot, the this variable containt its vendor
-    hr_laptop = {}
+    # if computer is notebook, the this variable containt its vendor
+    hr_laptop = {'hide':True}
+
+    # if computer is notebook, model name
+    hr_laptop_model = {'hide':True}
 
     # video verdor name
-    hr_video = {}
+    hr_video = {'hide':True}
 
     # Video driver used by xorg
-    os_x11_video_drv = {}
+    os_x11_video_drv = {'hide':True}
 
     # on/off composite mode
-    os_x11_composite = {}
+    os_x11_composite = {'hide':True}
 
     # current system is scratch
-    os_scratch = {}
+    os_scratch = {'hide':True}
 
     # programs have templates setup
-    cl_merges = {}
+    cl_merges = {'hide':True}
 
     # (on or off) autoupdate config from install program
-    cl_autoupdate_set = {'official':True, 'value': "off"}
+    cl_autoupdate_set = {'hide':True}
 
     # The path to the module api, and additional parameters caluclate packages
-    cl_api = {'official':True, 'value':{}}
+    cl_api = {'hide':True}
+
+    # base DN LDAP
+    ld_base_dn = {'hide':True}
+
+    # bind суффикс LDAP
+    ld_bind_dn = {'hide':True}
+
+    # bind name
+    ld_bind_login = {'hide':True}
+
+    # bind hash
+    ld_bind_hash = {'hide':True}
+
+    # bind password
+    ld_bind_pw = {'hide':True}
+
+    # hash crypto algoritm
+    ld_encrypt = {'hide':True}
+
+    # base name LDAP
+    ld_base_root = {'hide':True}
+
+    # admin DN
+    ld_admin_dn = {'hide':True}
+
+    # admin name LDAP
+    ld_admin_login = {'hide':True}
+
+    # admin hash
+    ld_admin_hash = {'hide':True}
+
+    # admin password
+    ld_admin_pw = {'hide':True}
+
+    # name from all services
+    ld_services= {'hide':True}
+
+    # DN from all services
+    ld_services_dn =  {'hide':True}
+
+    # CA certificate
+    cl_ca_cert = {'hide':True}
+
+    # CA key
+    cl_ca_key = {'hide':True}
+
+    # CA path
+    cl_ca_path = {'hide':True}
