@@ -18,8 +18,11 @@ import os
 import sys
 from cl_utils import getpathenv, runOsCommand, typeFile
 import re
-from os import path
-from cl_ldap import ldapUser
+from os import path, R_OK
+try:
+    from cl_ldap import ldapUser
+except ImportError:
+    ldapUser = None
 from operator import itemgetter
 
 class clLocale:
@@ -301,12 +304,13 @@ class varsShare:
         if userName:
             if userName in self._ldapUserData:
                 return self._ldapUserData[userName]
-            else:
+            elif not ldapUser is None:
                 ldapObj = self.getLdapUserObject()
-                userInfo = ldapObj.getUserLdapInfo(userName)
-                if userInfo:
-                    self._ldapUserData[userName] = userInfo
-                    return userInfo
+                if ldapObj:
+                    userInfo = ldapObj.getUserLdapInfo(userName)
+                    if userInfo:
+                        self._ldapUserData[userName] = userInfo
+                        return userInfo
         return {}
 
     def getLdapUserObject(self):
@@ -452,7 +456,7 @@ class varsShare:
         pkgInfoDir = path.join(systemroot,'var/db/pkg/app-misc/')
         if not os.access(pkgInfoDir,os.R_OK):
             return None
-        metaPkgs = filter(lambda x:"%s-meta"%shortname.lower() in x,
+        metaPkgs = filter(lambda x:"calculate-meta" in x,
                           os.listdir(pkgInfoDir))
         if metaPkgs:
             reFindVer = re.compile("(?<=\-)\d+\.?\d*\.?\d*")
@@ -505,3 +509,11 @@ class varsShare:
             reRes = reVer.search(kernelVersion)
             if reRes:
                 return reRes.group()
+
+    def isChroot(self,pid):
+        """Detect chroot mode by different mountinfo"""
+        if not os.access('/proc/self/mountinfo',R_OK) or \
+            not os.access('/proc/1/mountinfo',R_OK):
+            return False
+        return open('/proc/1/mountinfo','r').read() != \
+               open('/proc/self/mountinfo','r').read()
