@@ -14,7 +14,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-__version__ = "2.2.0.0"
+__version__ = "2.2.1"
 __app__ = "calculate-lib"
 
 import sys, os, stat, re
@@ -108,7 +108,6 @@ class DataVarsObject(cl_datavars.DataVars):
 
 class shareUpdateConfigs(color_print, writeLog):
     """Общие методы для обновления конфигурационных файлов"""
-    reCleanVer = re.compile("\d+\.?\d*\.?\d*")
     _tupleOn = ("on","On","oN","ON")
 
     def getFlagUpdAndInstPrograms(self):
@@ -157,9 +156,6 @@ class updateUserConfigs(shareUpdateConfigs):
             self.logger.info(_("Package %s") %nameProgram)
             self.logger.warn(_("Not found X sessions users"))
             return True
-        cleanVer = self.reCleanVer.search(version)
-        if cleanVer:
-            version = cleanVer.group()
         self.logger.info(_("Package %s") %nameProgram)
         self.logger.info(_("Update desktop configuration files"))
         if "calculate-desktop" in mergePrograms:
@@ -301,9 +297,6 @@ class updateSystemConfigs(shareUpdateConfigs):
             self.logger.info(_("Package %s") %nameProgram)
             self.logger.warn(_("Not found protected files"))
             return True
-        cleanVer = self.reCleanVer.search(version)
-        if cleanVer:
-            version = cleanVer.group()
         self.logger.info(_("Package %s") %nameProgram)
         self.logger.info(_("Update system cofiguration files"))
         if not os.path.exists(configPath):
@@ -328,13 +321,14 @@ class updateSystemConfigs(shareUpdateConfigs):
             nameProg = clVars.Get("cl_name")
             if nameProg == "calculate-install":
                 configFiles = self.scanProtectDirs(configPath)
-            cltObject = cl_template.templateClt(clVars)
             if configFiles:
+                cltObject = cl_template.templateClt(clVars)
                 cltObject.filterApplyTemplates = configFiles
-            else:
-                cltObject.filterApplyTemplates = []
-            clTempl = cl_template.template(clVars, cltObj=cltObject,
+                clTempl = cl_template.template(clVars, cltObj=cltObject,
                                            printWarning=False)
+            else:
+                clTempl = cl_template.template(clVars, cltObj=False,
+                                               printWarning=False)
             dirsFiles = clTempl.applyTemplates()
             nameAndVerPkg = nameProg + "-"+clVars.Get("cl_ver")
             if dirsFiles is False:
@@ -353,8 +347,11 @@ class updateSystemConfigs(shareUpdateConfigs):
                 self.printWARNING(_("Package %s has changed files")%calcPkg+":")
                 for nameF in dictPakkages[calcPkg]:
                     nameFile = nameF.partition(configPath)[2]
-                    if nameFile[:1] != "/":
-                        nameFile = "/" + nameFile
+                    if nameFile:
+                        if nameFile[:1] != "/":
+                            nameFile = "/" + nameFile
+                    else:
+                        nameFile = nameF
                     self.printWARNING(" "*5 + nameFile)
         else:
             self.logger.warn(_("Not found templates"))
